@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    crypto/signencrypttask.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -47,16 +45,28 @@ using namespace GpgME;
 namespace
 {
 
+struct LabelAndError {
+    QString label;
+    QString errorString;
+    QStringList fileNames;
+};
+
 class ErrorResult : public Task::Result
 {
 public:
-    ErrorResult(bool sign, bool encrypt, const Error &err, const QString &errStr, const QString &input, const QString &output, const AuditLogEntry &auditLog)
+    ErrorResult(bool sign,
+                bool encrypt,
+                const Error &err,
+                const QString &errStr,
+                const LabelAndError &input,
+                const QString &output,
+                const AuditLogEntry &auditLog)
         : Task::Result()
         , m_sign(sign)
         , m_encrypt(encrypt)
         , m_error(err)
         , m_errString(errStr)
-        , m_inputLabel(input)
+        , m_input(input)
         , m_outputLabel(output)
         , m_auditLog(auditLog)
     {
@@ -72,10 +82,6 @@ public:
     {
         return m_errString;
     }
-    VisualCode code() const override
-    {
-        return NeutralError;
-    }
     AuditLogEntry auditLog() const override
     {
         return m_auditLog;
@@ -86,20 +92,11 @@ private:
     const bool m_encrypt;
     const Error m_error;
     const QString m_errString;
-    const QString m_inputLabel;
+    const LabelAndError m_input;
     const QString m_outputLabel;
     const AuditLogEntry m_auditLog;
 };
 
-namespace
-{
-struct LabelAndError {
-    QString label;
-    QString errorString;
-    QStringList fileNames;
-};
-}
-
 class SignEncryptFilesResult : public Task::Result
 {
 public:
@@ -123,7 +120,6 @@ public:
     QString details() const override;
     GpgME::Error error() const override;
     QString errorString() const override;
-    VisualCode code() const override;
     AuditLogEntry auditLog() const override;
 
 private:
@@ -335,7 +331,7 @@ QString ErrorResult::overview() const
     Q_ASSERT(m_error || m_error.isCanceled());
     Q_ASSERT(m_sign || m_encrypt);
 
-    return formatResultLine({m_inputLabel}, m_outputLabel, m_sign, m_encrypt, true, true, m_error);
+    return formatResultLine(m_input.fileNames, m_outputLabel, m_sign, m_encrypt, true, true, m_error);
 }
 
 QString ErrorResult::details() const
@@ -367,7 +363,7 @@ private:
     std::unique_ptr<QGpgME::SignEncryptArchiveJob> createSignEncryptArchiveJob(GpgME::Protocol proto);
     std::unique_ptr<QGpgME::EncryptArchiveJob> createEncryptArchiveJob(GpgME::Protocol proto);
 
-    std::shared_ptr<const Task::Result> makeErrorResult(const Error &err, const QString &errStr, const AuditLogEntry &auditLog);
+    std::shared_ptr<const Task::Result> makeErrorResult(const Error &err, const QString &errStr, const AuditLogEntry &auditLog, const QStringList &fileNames);
 
 private:
     void slotResult(const SigningResult &);
@@ -383,7 +379,7 @@ private:
     QString outputFileName;
     std::vector<Key> signers;
     std::vector<Key> recipients;
-    bool isNotepad = false;
+    SignEncryptTask::DataSource dataSource = SignEncryptTask::DataSource::Files;
 
     bool sign : 1;
     bool encrypt : 1;
@@ -409,9 +405,10 @@ SignEncryptTask::Private::Private(SignEncryptTask *qq)
     q->setAsciiArmor(true);
 }
 
-std::shared_ptr<const Task::Result> SignEncryptTask::Private::makeErrorResult(const Error &err, const QString &errStr, const AuditLogEntry &auditLog)
+std::shared_ptr<const Task::Result>
+SignEncryptTask::Private::makeErrorResult(const Error &err, const QString &errStr, const AuditLogEntry &auditLog, const QStringList &fileNames)
 {
-    return std::shared_ptr<const ErrorResult>(new ErrorResult(sign, encrypt, err, errStr, inputLabel(), outputLabel(), auditLog));
+    return std::shared_ptr<const ErrorResult>(new ErrorResult(sign, encrypt, err, errStr, {inputLabel(), errStr, fileNames}, outputLabel(), auditLog));
 }
 
 SignEncryptTask::SignEncryptTask(QObject *p)
@@ -931,7 +928,7 @@ void SignEncryptTask::Private::slotResult(const QGpgME::Job *job, const SigningR
         if (output) {
             output->cancel();
         }
-        q->emitResult(makeErrorResult(Error::fromCode(GPG_ERR_EIO), i18n("Input error: %1", escape(input->errorString())), auditLog));
+        q->emitResult(makeErrorResult(Error::fromCode(GPG_ERR_EIO), i18n("Input error: %1", escape(input->errorString())), auditLog, inputFileNames));
         return;
     } else if (sresult.error().code() || eresult.error().code()) {
         if (output) {
@@ -958,7 +955,7 @@ void SignEncryptTask::Private::slotResult(const QGpgME::Job *job, const SigningR
                 input->finalize();
             }
         } catch (const GpgME::Exception &e) {
-            q->emitResult(makeErrorResult(e.error(), QString::fromLocal8Bit(e.what()), auditLog));
+            q->emitResult(makeErrorResult(e.error(), QString::fromLocal8Bit(e.what()), auditLog, inputFileNames));
             return;
         }
     }
@@ -966,13 +963,13 @@ void SignEncryptTask::Private::slotResult(const QGpgME::Job *job, const SigningR
     const LabelAndError inputInfo{inputLabel(), input ? input->errorString() : QString{}, inputFileNames};
     const LabelAndError outputInfo{outputLabel(), output ? output->errorString() : QString{}, {}};
     auto result = std::shared_ptr<Result>(new SignEncryptFilesResult(sresult, eresult, inputInfo, outputInfo, auditLog));
-    result->setIsNotepad(isNotepad);
+    result->setDataSource(dataSource);
     q->emitResult(result);
 }
 
 QString SignEncryptFilesResult::overview() const
 {
-    if (isNotepad()) {
+    if (dataSource() == Task::Notepad) {
         if (!m_sresult.isNull() && m_sresult.error()) {
             return i18nc("@info", "Failed to sign the notepad: %1", Formatting::errorAsString(m_sresult.error()));
         }
@@ -990,6 +987,24 @@ QString SignEncryptFilesResult::overview() const
         return {};
     }
 
+    if (dataSource() == Task::Clipboard) {
+        if (!m_sresult.isNull() && m_sresult.error()) {
+            return i18nc("@info", "Failed to sign the clipboard: %1", Formatting::errorAsString(m_sresult.error()));
+        }
+        if (!m_eresult.isNull() && m_eresult.error()) {
+            return i18nc("@info", "Failed to encrypt the clipboard: %1", Formatting::errorAsString(m_eresult.error()));
+        }
+
+        if (!m_sresult.isNull() && !m_eresult.isNull()) {
+            return i18nc("@info", "Successfully encrypted and signed the clipboard");
+        } else if (!m_eresult.isNull()) {
+            return i18nc("@info", "Successfully encrypted the clipboard");
+        } else {
+            return i18nc("@info", "Successfully signed the clipboard");
+        }
+        return {};
+    }
+
     return formatResultLine(m_input.fileNames,
                             m_output.label,
                             !m_sresult.isNull(),
@@ -1032,22 +1047,14 @@ QString SignEncryptFilesResult::errorString() const
                 : makeResultDetails(m_eresult, m_input.errorString, m_output.errorString);
 }
 
-Task::Result::VisualCode SignEncryptFilesResult::code() const
-{
-    if (m_sresult.error().isCanceled() || m_eresult.error().isCanceled()) {
-        return Warning;
-    }
-    return (m_sresult.error().code() || m_eresult.error().code()) ? NeutralError : NeutralSuccess;
-}
-
 AuditLogEntry SignEncryptFilesResult::auditLog() const
 {
     return m_auditLog;
 }
 
-void SignEncryptTask::setIsNotepad(bool isNotepad)
+void SignEncryptTask::setDataSource(Task::DataSource dataSource)
 {
-    d->isNotepad = isNotepad;
+    d->dataSource = dataSource;
 }
 
 #include "moc_signencrypttask.cpp"
