@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    mainwindow.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -759,14 +757,7 @@ void MainWindow::Private::setupActions()
                       coll);
     coll->addAction(QStringLiteral("help_doc_quickguide"), quickguide);
 
-    const auto symguide =
-        new DocAction(QIcon::fromTheme(QStringLiteral("help-contextual")),
-                      i18n("&Password-based Encryption"),
-                      i18nc("Only available in German and English. Leave to English for other languages.", "symmetric_encryption_gnupgvsd_en.pdf"),
-                      QStringLiteral("../share/doc/gnupg-vsd"),
-                      QUrl(),
-                      coll);
-    coll->addAction(QStringLiteral("help_doc_symenc"), symguide);
+    coll->addAction(QStringLiteral("help_doc_symenc"), createSymmetricGuideAction(coll).release());
 
     const auto groups = new DocAction(QIcon::fromTheme(QStringLiteral("help-contextual")),
                                       i18n("Certificate &Groups"),
@@ -846,11 +837,9 @@ void MainWindow::Private::slotConfigCommitted()
     updateStatusBar();
 }
 
-void MainWindow::closeEvent(QCloseEvent *e)
+bool MainWindow::queryClose()
 {
-    // KMainWindow::closeEvent() insists on quitting the application,
-    // so do not let it touch the event...
-    qCDebug(KLEOPATRA_LOG);
+    qCDebug(KLEOPATRA_LOG) << __func__;
     if (d->controller.hasRunningCommands()) {
         if (d->controller.shutdownWarningRequired()) {
             const int ret = KMessageBox::warningContinueCancel(this,
@@ -859,8 +848,7 @@ void MainWindow::closeEvent(QCloseEvent *e)
                                                                     "Proceed?"),
                                                                i18n("Ongoing Background Tasks"));
             if (ret != KMessageBox::Continue) {
-                e->ignore();
-                return;
+                return false;
             }
         }
         d->controller.cancelCommands();
@@ -871,20 +859,19 @@ void MainWindow::closeEvent(QCloseEvent *e)
             QTimer::singleShot(100ms, &ev, &QEventLoop::quit);
             connect(&d->controller, &KeyListController::commandsExecuting, &ev, &QEventLoop::quit);
             ev.exec();
-            if (d->controller.hasRunningCommands())
+            if (d->controller.hasRunningCommands()) {
                 qCWarning(KLEOPATRA_LOG) << "controller still has commands running, this may crash now...";
+            }
             setEnabled(true);
         }
     }
     unexportWindow();
     if (isQuitting || qApp->isSavingSession() || Kleo::userIsElevated()) {
         d->ui.searchTab->tabWidget()->saveViews();
-        KConfigGroup grp(KConfigGroup(KSharedConfig::openConfig(), autoSaveGroup()));
-        saveMainWindowSettings(grp);
-        e->accept();
+        return true;
     } else {
-        e->ignore();
         hide();
+        return false;
     }
 }
 
@@ -1002,5 +989,16 @@ KeyListController *MainWindow::keyListController()
     return &d->controller;
 }
 
+std::unique_ptr<DocAction> MainWindow::createSymmetricGuideAction(QObject *parent)
+{
+    return std::make_unique<DocAction>(
+        QIcon::fromTheme(QStringLiteral("help-contextual")),
+        i18n("&Password-based Encryption"),
+        i18nc("Only available in German and English. Leave to English for other languages.", "symmetric_encryption_gnupgvsd_en.pdf"),
+        QStringLiteral("../share/doc/gnupg-vsd"),
+        QUrl(),
+        parent);
+}
+
 #include "mainwindow.moc"
 #include "moc_mainwindow.cpp"
